==> starbase-0.3.tar.gz: starbase-0.3/src/starbase/client/transport/status_codes.py <==
__title__ = 'starbase.client.transport.status_codes'
__author__ = 'Artur Barseghyan'
__copyright__ = 'Copyright (c) 2013 Artur Barseghyan'
__license__ = 'GPL 2.0/LGPL 2.1'

# See the full list (http://www.w3.org/Protocols/rfc2616/rfc2616-sec10.html).
STATUS_CODE_OK = 200
STATUS_CODE_CREATED = 201
STATUS_CODE_ACCEPTED = 202
STATUS_CODE_NON_AUTHORATIVE_INFORMATION = 203
STATUS_CODE_NO_CONTENT = 204
STATUS_CODE_RESET_CONTENT = 205
STATUS_COE_PARTIAL_CONTENT = 206
STATUS_CODE_MULTIPLE_CHOICES = 300
STATUS_CODE_MOVED_PERMANENTLY = 301
STATUS_CODE_FOUND = 302
STATUS_CODE_SEE_OTHER = 303
STATUS_CODE_NOT_MODIFIED = 304
STATUS_CODE_USE_PROXY = 305
# 306 not used but reserved
STATUS_CODE_TEMPORARY_REDIRECT = 307
STATUS_CODE_BAD_REQUEST = 400
STATUS_CODE_UNAUTHORIZED = 401
STATUS_CODE_PAYMENT_REQUIRED = 402
STATUS_CODE_FORBIDDEN = 403
STATUS_CODE_NOT_FOUND = 404
STATUS_CODE_METHOD_NOT_ALLOWED = 405
STATUS_CODE_NOT_ACCEPTABLE = 406
STATUS_CODE_PROXY_AUTHENTICATION_REQUIRED = 407
STATUS_CODE_REQUEST_TIMEOUT = 408
STATUS_CODE_CONFLICT = 409
STATUS_CODE_GONE = 410
STATUS_CODE_LENGTH_REQUIRED = 411
STATUS_CODE_PRECONDITION_FAILED = 412
STATUS_CODE_REQUEST_ENTRY_TOO_LARGE = 413
STATUS_CODE_REQUEST_URI_TOO_LONG = 414
STATUS_CODE_UNSUPPORTED_MEDIA_TYPE = 415
STATUS_CODE_REQUESTED_RANGE_NOT_SATISFIABLE = 416
STATUS_CODE_EXPECTATION_FAILED = 417
STATUS_CODE_INTERNAL_SERVER_ERROR = 500
STATUS_CODE_NOT_IMPLEMENTED = 501
STATUS_CODE_BAD_GATEWAY = 502
STATUS_CODE_SERVICE_UNAVAILABLE = 503
STATUS_CODE_GATEWAY_TIMEOUT = 504
STATUS_CODE_HTTP_VERSION_NOT_SUPPORTED = 505

==> starbase-0.3.3.tar.gz: starbase-0.3.3/src/starbase/client/transport/status_codes.py <==
__title__ = 'starbase.client.transport.status_codes'
__author__ = 'Artur Barseghyan'
__copyright__ = 'Copyright (c) 2013-2014 Artur Barseghyan'
__license__ = 'GPL 2.0/LGPL 2.1'

# See the full list (http://www.w3.org/Protocols/rfc2616/rfc2616-sec10.html).
STATUS_CODE_OK = 200
STATUS_CODE_CREATED = 201
STATUS_CODE_ACCEPTED = 202
STATUS_CODE_NON_AUTHORATIVE_INFORMATION = 203
STATUS_CODE_NO_CONTENT = 204
STATUS_CODE_RESET_CONTENT = 205
STATUS_COE_PARTIAL_CONTENT = 206
STATUS_CODE_MULTIPLE_CHOICES = 300
STATUS_CODE_MOVED_PERMANENTLY = 301
STATUS_CODE_FOUND = 302
STATUS_CODE_SEE_OTHER = 303
STATUS_CODE_NOT_MODIFIED = 304
STATUS_CODE_USE_PROXY = 305
# 306 not used but reserved
STATUS_CODE_TEMPORARY_REDIRECT = 307
STATUS_CODE_BAD_REQUEST = 400
STATUS_CODE_UNAUTHORIZED = 401
STATUS_CODE_PAYMENT_REQUIRED = 402
STATUS_CODE_FORBIDDEN = 403
STATUS_CODE_NOT_FOUND = 404
STATUS_CODE_METHOD_NOT_ALLOWED = 405
STATUS_CODE_NOT_ACCEPTABLE = 406
STATUS_CODE_PROXY_AUTHENTICATION_REQUIRED = 407
STATUS_CODE_REQUEST_TIMEOUT = 408
STATUS_CODE_CONFLICT = 409
STATUS_CODE_GONE = 410
STATUS_CODE_LENGTH_REQUIRED = 411
STATUS_CODE_PRECONDITION_FAILED = 412
STATUS_CODE_REQUEST_ENTRY_TOO_LARGE = 413
STATUS_CODE_REQUEST_URI_TOO_LONG = 414
STATUS_CODE_UNSUPPORTED_MEDIA_TYPE = 415
STATUS_CODE_REQUESTED_RANGE_NOT_SATISFIABLE = 416
STATUS_CODE_EXPECTATION_FAILED = 417
STATUS_CODE_INTERNAL_SERVER_ERROR = 500
STATUS_CODE_NOT_IMPLEMENTED = 501
STATUS_CODE_BAD_GATEWAY = 502
STATUS_CODE_SERVICE_UNAVAILABLE = 503
STATUS_CODE_GATEWAY_TIMEOUT = 504
STATUS_CODE_HTTP_VERSION_NOT_SUPPORTED = 505

BAD_STATUS_CODES = set([
    STATUS_CODE_BAD_REQUEST,
    STATUS_CODE_UNAUTHORIZED,
    STATUS_CODE_PAYMENT_REQUIRED,
    STATUS_CODE_FORBIDDEN,
    STATUS_CODE_NOT_FOUND,
    STATUS_CODE_METHOD_NOT_ALLOWED,
    STATUS_CODE_NOT_ACCEPTABLE,
    STATUS_CODE_PROXY_AUTHENTICATION_REQUIRED,
    STATUS_CODE_REQUEST_TIMEOUT,
    STATUS_CODE_CONFLICT,
    STATUS_CODE_GONE,
    STATUS_CODE_LENGTH_REQUIRED,
    STATUS_CODE_PRECONDITION_FAILED,
    STATUS_CODE_REQUEST_ENTRY_TOO_LARGE,
    STATUS_CODE_REQUEST_URI_TOO_LONG,
    STATUS_CODE_UNSUPPORTED_MEDIA_TYPE,
    STATUS_CODE_REQUESTED_RANGE_NOT_SATISFIABLE,
    STATUS_CODE_EXPECTATION_FAILED,
    STATUS_CODE_INTERNAL_SERVER_ERROR,
    STATUS_CODE_NOT_IMPLEMENTED,
    STATUS_CODE_BAD_GATEWAY,
    STATUS_CODE_SERVICE_UNAVAILABLE,
    STATUS_CODE_GATEWAY_TIMEOUT,
    STATUS_CODE_HTTP_VERSION_NOT_SUPPORTED
    ])
